<?php
/**
 * Physiotherapy Lite Theme Customizer
 *
 * @package Physiotherapy Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function physiotherapy_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'physiotherapy_lite_custom_controls' );

function physiotherapy_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'physiotherapy_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'physiotherapy-lite' ),
	) );

	// Layout
	$wp_customize->add_section( 'physiotherapy_lite_left_right', array(
    	'title'      => __( 'General Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_width_option',array(
        'default' => __('Full Width','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','physiotherapy-lite'),
        'description' => __('Here you can change the width layout of Website.','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('physiotherapy_lite_theme_options',array(
        'default' => __('Right Sidebar','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite'),
            'Three Columns' => __('Three Columns','physiotherapy-lite'),
            'Four Columns' => __('Four Columns','physiotherapy-lite'),
            'Grid Layout' => __('Grid Layout','physiotherapy-lite')
        ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_page_layout',array(
        'default' => __('One Column','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite')
        ),
	) );

	//Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'physiotherapy_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_left_right'
    )));

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'physiotherapy_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_left_right'
    )));

	//Pre-Loader
	$wp_customize->add_setting( 'physiotherapy_lite_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_left_right'
    )));

	$wp_customize->add_setting('physiotherapy_lite_loader_icon',array(
        'default' => __('Two Way','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','physiotherapy-lite'),
            'Dots' => __('Dots','physiotherapy-lite'),
            'Rotate' => __('Rotate','physiotherapy-lite')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'physiotherapy_lite_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_topbar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_topbar_hide_show',array(
		'label' => esc_html__( 'Show / Hide Topbar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_topbar'
    )));

    //Sticky Header
	$wp_customize->add_setting( 'physiotherapy_lite_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_topbar'
    )));

	$wp_customize->add_setting( 'physiotherapy_lite_header_cart',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_cart',array(
      	'label' => esc_html__( 'Show / Hide Cart','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));
	
	$wp_customize->add_setting( 'physiotherapy_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));

    $wp_customize->add_setting('physiotherapy_lite_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_phone_icon',array(
		'label'	=> __('Add Phone Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_call',array(
		'label'	=> __('Add Phone Number','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 567 890', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_header_cart_icon',array(
		'default'	=> 'fas fa-shopping-basket',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_header_cart_icon',array(
		'label'	=> __('Add Cart Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_header_cart_icon',
		'type'		=> 'icon'
	)));
    
	//Slider
	$wp_customize->add_section( 'physiotherapy_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_slider_arrows',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'physiotherapy_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'physiotherapy_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'physiotherapy_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'physiotherapy-lite' ),
			'description' => __('Slider image size (1600 x 600)','physiotherapy-lite'),
			'section'  => 'physiotherapy_lite_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('physiotherapy_lite_slider_content_option',array(
        'default' => __('Center','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'physiotherapy_lite_slider_excerpt_number', array(
		'default'              => 20,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'physiotherapy_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'physiotherapy_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('physiotherapy_lite_slider_opacity_color',array(
      'default'              => 0.3,
      'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'physiotherapy_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','physiotherapy-lite' ),
	'section'     => 'physiotherapy_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'physiotherapy_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','physiotherapy-lite'),
      '0.1' =>  esc_attr('0.1','physiotherapy-lite'),
      '0.2' =>  esc_attr('0.2','physiotherapy-lite'),
      '0.3' =>  esc_attr('0.3','physiotherapy-lite'),
      '0.4' =>  esc_attr('0.4','physiotherapy-lite'),
      '0.5' =>  esc_attr('0.5','physiotherapy-lite'),
      '0.6' =>  esc_attr('0.6','physiotherapy-lite'),
      '0.7' =>  esc_attr('0.7','physiotherapy-lite'),
      '0.8' =>  esc_attr('0.8','physiotherapy-lite'),
      '0.9' =>  esc_attr('0.9','physiotherapy-lite')
	),
	));
 
	//Services
	$wp_customize->add_section('physiotherapy_lite_services',array(
		'title'	=> __('Services Section','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_text',array(
		'label'	=> __('Section Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('physiotherapy_lite_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_title',array(
		'label'	=> __('Section Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'OUR PHYSIOTHERAPY', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('physiotherapy_lite_services_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('physiotherapy_lite_services_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','physiotherapy-lite'),
		'section' => 'physiotherapy_lite_services',
	));

	//Blog Post
	$wp_customize->add_section('physiotherapy_lite_blog_post',array(
		'title'	=> __('Blog Post Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	

	$wp_customize->add_setting( 'physiotherapy_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_blog_post'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_author',array(
		'label' => esc_html__( 'Author','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_blog_post'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_comments',array(
		'label' => esc_html__( 'Comments','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_blog_post'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_excerpt_number', array(
		'default'              => 20,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'physiotherapy_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_blog_post',
		'type'        => 'range',
		'settings'    => 'physiotherapy_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog layout
    $wp_customize->add_setting('physiotherapy_lite_blog_layout_option',array(
        'default' => __('Default','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
    ));
    $wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_blog_post',
        'choices' => array(
            'Default' => get_template_directory_uri().'/assets/images/blog-layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/blog-layout2.png',
            'Left' => get_template_directory_uri().'/assets/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('physiotherapy_lite_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_text',array(
		'label'	=> __('Add Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'READ MORE', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_blog_post',
		'type'=> 'text'
	));

    //404 Page Setting
	$wp_customize->add_section('physiotherapy_lite_404_page',array(
		'title'	=> __('404 Page Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_404_page_title',array(
		'label'	=> __('Add Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_404_page_content',array(
		'label'	=> __('Add Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_404_page_button_text',array(
		'label'	=> __('Add Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('physiotherapy_lite_responsive_media',array(
		'title'	=> __('Responsive Media','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));

	$wp_customize->add_setting( 'physiotherapy_lite_resp_topbar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_resp_topbar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Topbar','physiotherapy-lite' ),
          'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_stickyheader_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_stickyheader_hide_show',array(
          'label' => esc_html__( 'Sticky Header','physiotherapy-lite' ),
          'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_resp_slider_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_resp_slider_hide_show',array(
          'label' => esc_html__( 'Show / Hide Slider','physiotherapy-lite' ),
          'section' => 'physiotherapy_lite_responsive_media'
    )));

	$wp_customize->add_setting( 'physiotherapy_lite_metabox_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_metabox_hide_show',array(
          'label' => esc_html__( 'Show / Hide Metabox','physiotherapy-lite' ),
          'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_sidebar_hide_show',array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_sidebar_hide_show',array(
          'label' => esc_html__( 'Show / Hide Sidebar','physiotherapy-lite' ),
          'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting('physiotherapy_lite_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_responsive_media',
		'setting'	=> 'physiotherapy_lite_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_res_close_menus_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_res_close_menus_icon',array(
		'label'	=> __('Add Close Menu Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_responsive_media',
		'setting'	=> 'physiotherapy_lite_res_close_menus_icon',
		'type'		=> 'icon'
	)));

	//Content Creation
	$wp_customize->add_section( 'physiotherapy_lite_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'physiotherapy-lite' ),
		'priority' => null,
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new Physiotherapy_Lite_Content_Creation( $wp_customize, 'physiotherapy_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','physiotherapy-lite' ),
		),
		'section' => 'physiotherapy_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'physiotherapy-lite' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('physiotherapy_lite_footer',array(
		'title'	=> __('Footer Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	
	
	$wp_customize->add_setting('physiotherapy_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_footer_text',array(
		'label'	=> __('Copyright Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_footer'
    )));

    $wp_customize->add_setting('physiotherapy_lite_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_footer',
		'setting'	=> 'physiotherapy_lite_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_scroll_top_alignment',array(
        'default' => __('Right','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'settings' => 'physiotherapy_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'physiotherapy_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Physiotherapy_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Physiotherapy_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Physiotherapy_Lite_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 1,
			'title'    => esc_html__( 'PHYSIOTHERAPY PRO', 'physiotherapy-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'physiotherapy-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/'),
		) )	);

		$manager->add_section(new Physiotherapy_Lite_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'physiotherapy-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'physiotherapy-lite' ),
			'pro_url'  => admin_url('themes.php?page=physiotherapy_lite_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'physiotherapy-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'physiotherapy-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Physiotherapy_Lite_Customize::get_instance();